@@ -809,7 +809,7 @@ library(biomaRt)
 bm <- useMart(host="may2012.archive.ensembl.org", biomart="ENSEMBL_MART_ENSEMBL",
               dataset="hsapiens_gene_ensembl")
 fm <- Gviz:::.getBMFeatureMap()
-fm["symbol"] <- "external_gene_id"
+fm[["symbol"]] <- "external_gene_id"
 biomTrack <- BiomartGeneRegionTrack(genome="hg19", chromosome="chr7", start=20e6, end=21e6,name="ENSEMBL",
                                     featureMap=fm, biomart=bm)
 plotTracks(biomTrack, col.line=NULL, col=NULL, stackHeight=0.3)
